@@ -17,8 +17,8 @@ ContextAsyncTuning = R6Class("ContextAsyncTuning",
   active = list(
 
     #' @field xs_learner (list())\cr
-    #'   The hyperparameter configuration currently evaluated.
-    #'   Contains the values on the learner scale i.e. transformations are applied.
+    #' The hyperparameter configuration currently evaluated.
+    #' Contains the values on the learner scale i.e. transformations are applied.
     xs_learner = function(rhs) {
       if (missing(rhs)) {
         return(get_private(self$instance$objective)$.xs)
@@ -28,7 +28,7 @@ ContextAsyncTuning = R6Class("ContextAsyncTuning",
     },
 
     #' @field resample_result ([mlr3::BenchmarkResult])\cr
-    #'   The resample result of the hyperparameter configuration currently evaluated.
+    #' The resample result of the hyperparameter configuration currently evaluated.
     resample_result = function(rhs) {
       if (missing(rhs)) {
         return(get_private(self$instance$objective)$.resample_result)
@@ -38,15 +38,25 @@ ContextAsyncTuning = R6Class("ContextAsyncTuning",
     },
 
     #' @field aggregated_performance (`list()`)\cr
-    #'   Aggregated performance scores and training time of the evaluated hyperparameter configuration.
-    #'   This list is passed to the archive.
-    #'   A callback can add additional elements which are also written to the archive.
+    #' Aggregated performance scores and training time of the evaluated hyperparameter configuration.
+    #' This list is passed to the archive.
+    #' A callback can add additional elements which are also written to the archive.
     aggregated_performance = function(rhs) {
       if (missing(rhs)) {
         return(get_private(self$instance$objective)$.aggregated_performance)
       } else {
         self$instance$objective$.__enclos_env__$private$.aggregated_performance = rhs
       }
+    },
+
+    #' @field result_learner_param_vals (list())\cr
+    #' The learner parameter values passed to `instance$assign_result()`.
+    result_learner_param_vals = function(rhs) {
+      if (missing(rhs)) {
+        return(get_private(self$instance)$.result_learner_param_vals)
+      } else {
+        self$instance$.__enclos_env__$private$.result_learner_param_vals = rhs
+      }
     }
   )
 )
